Documentation
¶
Index ¶
- Constants
- func CronFireKey(name string, tickUnix int64) string
- func CronFirePrefix(name string) string
- func CronJobKey(name string) string
- func CronJobPrefix() string
- func CronResultKey(name string, tickUnix int64) string
- func CronResultPrefix(name string) string
- func ElectElectionKey(office string) string
- func ElectPrefix(office string) string
- func NewHolderJSON(cmdArgs []string) ([]byte, error)
- func SemaKey(name string, max int, spread bool, host string, leaseID int64) string
- func SemaPrefix(name string, max int) string
- type Backoff
- type CoreSession
- type Holder
- type HolderJSON
- type Outcome
- type RunConfig
Constants ¶
const PrefixV1 = "/conch/v1"
Variables ¶
This section is empty.
Functions ¶
func CronFireKey ¶
CronFireKey is the fire key for a job's specific tick
func CronFirePrefix ¶
CronFirePrefix is the prefix for all tick fire keys of a job
func CronResultKey ¶
CronResultKey is the result key for a job's specific tick
func CronResultPrefix ¶
CronResultPrefix is the prefix for all results of a job
func ElectElectionKey ¶
ElectElectionKey is passed to concurrency.NewElection (without trailing slash)
func ElectPrefix ¶
ElectPrefix is used to watch or fetch candidates for an office
func NewHolderJSON ¶
func SemaPrefix ¶
SemaPrefix is the prefix for a semaphore name and capacity
Types ¶
type Backoff ¶
type Backoff struct {
Base time.Duration
Cap time.Duration
// contains filtered or unexported fields
}
func NewBackoff ¶
type CoreSession ¶
type CoreSession struct {
Client *clientv3.Client
Session *concurrency.Session
LeaseID clientv3.LeaseID
DoneCh <-chan struct{}
}
func NewCoreSession ¶
func (*CoreSession) Close ¶
func (cs *CoreSession) Close()
type HolderJSON ¶
Click to show internal directories.
Click to hide internal directories.